function [Dc, Lc] = rscode(Do)
% RSCODE - Code a design matrix Do, so that the maximum value in every column is mapped to +1 and the minimum value into -1. Version 0.1.8.
%
% The syntax is
% [Dc, L] = rscode(Do)
%
% Arguments
% Do is the original design matrix that should be coded.
%
% Return values
% Dc is the +/-1 coded design matrix.
% L is the scaling matrix such that Xc=Xo*L, where Xc and Xo are obtained from Dc and Do, respectively, by adding an N by 1 column vector of ones at the left.
%
% References
% No reference needed, this is a trivial interface for rsscale.


% Copyright (C) 2015 Mikael Kurula <mkurula@abo.fi>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, see <http://www.gnu.org/licenses/>.
%
% Author: Mikael Kurula <mkurula@abo.fi>, 2015


% Check input
if nargin ~= 1 ,
    error('Try help rsscale for instructions.') ;
end

% Perform coding
k=size(Do,2);
[~, Lc, Dc]=rsscale(Do, [-ones(k,1) ones(k,1)]);

end