function rsplot(xl, yl, titl, leg, plt, prefix, errbr)
% RSPLOT - Easy export of a plot to a PDF file. Version 0.1.28.
%
% The syntax is
% rsplot(xl, yl, titl, leg, plt, [prefix], [errbr])
%
% Arguments
% xl is a string containing the label of the x-axis
% yl is a string containing the label of the y-axis
% titl is a string containing the title of the plot
% leg is a cell with one row containing strings for the legend, e.g., {'Curve 1','Curve 2'}
% plt is a list of lists to send to the plot command, e.g. {{x1,y1},{x2,y2,'rd','markersize',10}}
% [prefix] is a voluntary string to use in the naming of the output file. No prefix leads to no file.
% [errbr] plot errorbars; the syntax is the same as for the errorbar
% command. If errorbars are desired without 
% Any or all of xl, yl, titl, leg can be set to [] for elements that should be omitted from the plot.


% Copyright (C) 2016 Mikael Kurula <mkurula@abo.fi>
%
% This program is free software; you can redistribute it and/or modify it under
% the terms of the GNU General Public License as published by the Free Software
% Foundation; either version 3 of the License, or (at your option) any later
% version.
%
% This program is distributed in the hope that it will be useful, but WITHOUT
% ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
% FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for more
% details.
%
% You should have received a copy of the GNU General Public License along with
% this program; if not, see <http://www.gnu.org/licenses/>.
%
% Author: Mikael Kurula <mkurula@abo.fi>, 2016


% Check input
if nargin < 5 || nargin > 7,
    error('Try help rsplot for instructions.') ;
end

% Take care of differences between Octave and Matlab
if exist ('OCTAVE_VERSION', 'builtin')       % Are we running Octave?
   graphics_toolkit('gnuplot')
   PprSz=[6 4];
else
   PprSz=[12 8];
end 

f=figure('PaperPosition',[0 0 PprSz],'PaperSize',PprSz); 

if nargin==7
    errorbar(errbr{:})
end

hold on
for i = 1:length(plt)
    plot(plt{i}{:})
end
hold off
if size(titl,1)>0
  title(titl)
end 
if size(xl,1)>0
  xlabel(xl)
end 
if size(yl,1)>0
  ylabel(yl)
end 
if size(leg,1)>0
  legend(leg)
end

if nargin>5 && size(prefix,1)>0
  print([prefix,'-rsplot'],'-dpdf')
end

end